pub struct Hunk {
pub file: usize,
pub old_start: u32,
pub old_count: u32,
pub new_start: u32,
pub new_count: u32,
pub removed: Vec<Line>,
pub added: Vec<Line>,
pub nonl_old: bool,
pub nonl_new: bool,
}Expand description
One canonical hunk from git diff -U0 --no-renames.
Fields
file: usizeIndex into the canonical file vector.
old_start: u32old_count: u32new_start: u32new_count: u32removed: Vec<Line>Removed lines, without prefix or newline.
added: Vec<Line>Added lines, without prefix or newline.
nonl_old: bool\ No newline at end of file on the old side.
nonl_new: bool\ No newline at end of file on the new side.