RefWriter

Trait RefWriter 

pub trait RefWriter {
    // Required method
    fn update_ref(&self, name: &str, target: &str) -> Result<(), EngineError>;
}
update-ref. The only port in the engine that mutates repository state a user can see, with exactly one consumer: the shadow-branch renderer.

Required Methods

fn update_ref(&self, name: &str, target: &str) -> Result<(), EngineError>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors